#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-src-exts-util
version:              0.2.5
visibility:           public
id:                   haskell-src-exts-util-0.2.5-Dv8cYuMY2SZ731CFae99aE
key:                  haskell-src-exts-util-0.2.5-Dv8cYuMY2SZ731CFae99aE
license:              BSD-3-Clause
copyright:            All Rights Reserved
maintainer:           pepeiborra@gmail.com
author:               Neil Mitchell, Jose Iborra
homepage:             https://github.com/pepeiborra/haskell-src-exts-util
synopsis:             Helper functions for working with haskell-src-exts trees
description:          Helper functions for working with haskell-src-exts trees.
category:             language
abi:                  4b551916283047f8e46ef14daac1f9e4
exposed:              True
exposed-modules:      Language.Haskell.Exts.Util
hidden-modules:
    Language.Haskell.Exts.Bracket Language.Haskell.Exts.FreeVars
    Language.Haskell.Exts.Util.Internal Paths_haskell_src_exts_util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/haskell-src-exts-util-0.2.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/haskell-src-exts-util-0.2.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/haskell-src-exts-util-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-exts-util
hs-libraries:         HShaskell-src-exts-util-0.2.5-Dv8cYuMY2SZ731CFae99aE
depends:
    base-4.18.2.1 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    haskell-src-exts-1.23.1-Dek69H7qjWHIVXzgKLUjQ transformers-0.6.1.0
    uniplate-1.6.13-9A5kZUMYPMLG8f1cV35ueu

haddock-interfaces:
    /usr/share/doc/haskell-src-exts-util/html/haskell-src-exts-util.haddock

haddock-html:         /usr/share/doc/haskell-src-exts-util/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

